@@ -1,4 +1,4 @@
-# ABSTRACT: Perl 5 API wrapper for Basecamp
+# ABSTRACT: Perl 5 API wrapper for Basecamp.com
 package API::Basecamp;
 
 use API::Basecamp::Class;
@@ -8,35 +8,35 @@ extends 'API::Basecamp::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 has account => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has identifier => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     default  => 'API::Basecamp (Perl)',
 );
 
 has username => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has password => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has version => (
     is       => 'rw',
-    isa      => INTEGER,
+    isa      => Int,
     default  => 1,
 );
 
@@ -141,11 +141,11 @@ __END__
 
 =head1 NAME
 
-API::Basecamp - Perl 5 API wrapper for Basecamp
+API::Basecamp - Perl 5 API wrapper for Basecamp.com
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -410,9 +410,9 @@ used in all HTTP requests. This attribute expects a L<Mojo::UserAgent> object.
 
     # e.g.
 
-    $basecamp->action('head', %args);   # HEAD request
-    $basecamp->action('optons', %args); # OPTIONS request
-    $basecamp->action('patch', %args);  # PATCH request
+    $basecamp->action('head', %args);    # HEAD request
+    $basecamp->action('options', %args); # OPTIONS request
+    $basecamp->action('patch', %args);   # PATCH request
 
 The action method issues a request to the API resource represented by the
 object. The first parameter will be used as the HTTP request method. The
@@ -494,7 +494,7 @@ can be used to find more information. L<https://github.com/basecamp/bcx-api/blob
 The calendar_events method returns a new instance representative of the API
 I<Calendar Events> resource requested. This method accepts a list of path
 segments which will be used in the HTTP request. The following documentation
-can be used to find more information. L<>.
+can be used to find more information. L<https://github.com/basecamp/bcx-api/blob/master/sections/calendar_events.md>.
 
 =head2 calendars
 
